[commit] r2557 - in trunk: Doc Install SDK/BON/Common SDK/BON/Wizard SDK/BON/Wizard/Scripts/1033 SDK/BON/Wizard/Templates/1033

GMESRC Repository Notifications gme-commit at list.isis.vanderbilt.edu
Wed Oct 29 10:43:40 CDT 2014


Author: ksmyth
Date: Wed Oct 29 10:43:40 2014
New Revision: 2557

Log:
VC wizard: support VS2013. Some UNICODE fixes.

Added:
   trunk/SDK/BON/Wizard/setup12.js
      - copied, changed from r2556, trunk/SDK/BON/Wizard/setup11.js
Modified:
   trunk/Doc/README_in.txt
   trunk/Install/GME_SDK.wxs
   trunk/SDK/BON/Common/ComponentObj.cpp
   trunk/SDK/BON/Common/Exceptions.h
   trunk/SDK/BON/Common/targetver.h
   trunk/SDK/BON/Wizard/Scripts/1033/default.js
   trunk/SDK/BON/Wizard/Templates/1033/BON2Component.cpp
   trunk/SDK/BON/Wizard/Templates/1033/BONComponent.cpp
   trunk/SDK/BON/Wizard/Templates/1033/RawComponent.cpp
   trunk/SDK/BON/Wizard/setup11.js

Modified: trunk/Doc/README_in.txt
==============================================================================
--- trunk/Doc/README_in.txt	Tue Oct 21 10:18:41 2014	(r2556)
+++ trunk/Doc/README_in.txt	Wed Oct 29 10:43:40 2014	(r2557)
@@ -29,6 +29,7 @@
 ----------------------------------
   - Binary compatibility with 11.12.2
   - CSharpComponentWizard: support for Visual Studio 2013
+  - VC component wizard: support for Visual Studio 2013
   - Fix bug with addon notification where addons wouldn't get notified under certain circumstances, like registry edits
 
 Release Notes of Release 14.10.10

Modified: trunk/Install/GME_SDK.wxs
==============================================================================
--- trunk/Install/GME_SDK.wxs	Tue Oct 21 10:18:41 2014	(r2556)
+++ trunk/Install/GME_SDK.wxs	Wed Oct 29 10:43:40 2014	(r2557)
@@ -730,6 +730,7 @@
         <File Id="setup90.js" Name="setup90.js"  Source="..\SDK\BON\Wizard\setup90.js" />
         <File Id="setup100.js" Name="setup100.js"  Source="..\SDK\BON\Wizard\setup100.js" />
         <File Id="setup110.js" Name="setup11.js"  Source="..\SDK\BON\Wizard\setup11.js" />
+        <File Id="setup12.js" Name="setup12.js"  Source="..\SDK\BON\Wizard\setup12.js" />
       </Component>
 
       <Component Id="BONWizard1033Files" Guid="{3183F8EB-28B7-433A-B645-E8BB483F7021}" Directory="INSTALLDIR_SDK_BON_WIZARD_1033">

Modified: trunk/SDK/BON/Common/ComponentObj.cpp
==============================================================================
--- trunk/SDK/BON/Common/ComponentObj.cpp	Tue Oct 21 10:18:41 2014	(r2556)
+++ trunk/SDK/BON/Common/ComponentObj.cpp	Wed Oct 29 10:43:40 2014	(r2557)
@@ -56,11 +56,11 @@
 #define _OLESTR(x) OLESTR(x)
 extern const char* g_COCLASS_PROGIDA = COCLASS_PROGID;
 extern const wchar_t* g_COCLASS_PROGIDW = _OLESTR(COCLASS_PROGID);
-extern const char* g_COMPONENT_NAMEA = COMPONENT_NAME;
-extern const wchar_t* g_COMPONENT_NAMEW = _OLESTR(COMPONENT_NAME);
 #ifdef UNICODE
-extern const TCHAR* g_COMPONENT_NAME = g_COMPONENT_NAMEW;
+extern const TCHAR* g_COMPONENT_NAME = COMPONENT_NAME;
 #else
+extern const char* g_COMPONENT_NAMEA = COMPONENT_NAME;
+extern const wchar_t* g_COMPONENT_NAMEW = _OLESTR(COMPONENT_NAME);
 extern const TCHAR* g_COMPONENT_NAME = g_COMPONENT_NAMEA;
 #endif
 #ifdef REGISTER_SYSTEMWIDE

Modified: trunk/SDK/BON/Common/Exceptions.h
==============================================================================
--- trunk/SDK/BON/Common/Exceptions.h	Tue Oct 21 10:18:41 2014	(r2556)
+++ trunk/SDK/BON/Common/Exceptions.h	Wed Oct 29 10:43:40 2014	(r2557)
@@ -51,7 +51,7 @@
 			}
 
 			BON::Exception exception(hr, "?");
-			exception << static_cast<const TCHAR*>(bstr);
+			exception << static_cast<const char*>(bstr);
 			throw exception;
 		} else {
 			if (supportErrorInfo != NULL) {

Modified: trunk/SDK/BON/Common/targetver.h
==============================================================================
--- trunk/SDK/BON/Common/targetver.h	Tue Oct 21 10:18:41 2014	(r2556)
+++ trunk/SDK/BON/Common/targetver.h	Wed Oct 29 10:43:40 2014	(r2557)
@@ -8,19 +8,19 @@
 
 // Modify the following defines if you have to target a platform prior to the ones specified below.
 // Refer to MSDN for the latest info on corresponding values for different platforms.
-#ifndef WINVER                          // Specifies that the minimum required platform is Windows 2000.
-#define WINVER 0x0500           // Change this to the appropriate value to target other versions of Windows.
+#ifndef WINVER
+#define WINVER 0x0501
 #endif
 
-#ifndef _WIN32_WINNT            // Specifies that the minimum required platform is Windows 2000.
-#define _WIN32_WINNT 0x0500     // Change this to the appropriate value to target other versions of Windows.
+#ifndef _WIN32_WINNT
+#define _WIN32_WINNT _WIN32_WINNT_WINXP
 #endif
 
-#ifndef _WIN32_WINDOWS          // Specifies that the minimum required platform is Windows Me.
-#define _WIN32_WINDOWS 0x0500 // Change this to the appropriate value to target Windows Me or later.
+#ifndef _WIN32_WINDOWS
+#define _WIN32_WINDOWS 0x0501
 #endif
 
-#ifndef _WIN32_IE                       // Specifies that the minimum required platform is Internet Explorer 5.5.
-#define _WIN32_IE 0x0550        // Change this to the appropriate value to target other versions of IE.
+#ifndef _WIN32_IE
+#define _WIN32_IE 0x0550
 #endif
 

Modified: trunk/SDK/BON/Wizard/Scripts/1033/default.js
==============================================================================
--- trunk/SDK/BON/Wizard/Scripts/1033/default.js	Tue Oct 21 10:18:41 2014	(r2556)
+++ trunk/SDK/BON/Wizard/Scripts/1033/default.js	Wed Oct 29 10:43:40 2014	(r2557)
@@ -8,6 +8,9 @@
         else if (dte.Version == '11.0') {
             OnFinish100(selProj, selObj);
         }
+        else if (dte.Version == '12.0') {
+            OnFinish100(selProj, selObj);
+        }
 		else {
 		    OnFinish90(selProj, selObj);
 		}
@@ -86,7 +89,7 @@
 
 function CreateCoClassUUIDExploded()
 {
-    // Altenative representation of the CoClass UUID
+    // Alternative representation of the CoClass UUID
 	var CoClassUUID = wizard.FindSymbol('COCLASS_UUID');
 	var CoClassGUID2 = wizard.FormatGuid('{' + CoClassUUID + '}', 1);
 	var exploded = CoClassGUID2.split(",");
@@ -176,10 +179,17 @@
     var config = proj.Object.Configurations('Debug');
     var MIDLTool = config.Tools('VCMIDLTool');
     MIDLTool.TypeLibraryName = "$(ProjectDir)%(FileName).tlb";
+    if (dte.Version == '12.0' ) {
+        // http://blogs.msdn.com/b/vcblog/archive/2013/07/08/mfc-support-for-mbcs-deprecated-in-visual-studio-2013.aspx
+        config.CharacterSet = charSetUNICODE;
+    }
     
     config = proj.Object.Configurations('Release');
     MIDLTool = config.Tools('VCMIDLTool');
     MIDLTool.TypeLibraryName = "$(ProjectDir)%(FileName).tlb";
+    if (dte.Version == '12.0' ) {
+        config.CharacterSet = charSetUNICODE;
+    }
 }
 
 function AddConfig90(proj, strProjectName)

Modified: trunk/SDK/BON/Wizard/Templates/1033/BON2Component.cpp
==============================================================================
--- trunk/SDK/BON/Wizard/Templates/1033/BON2Component.cpp	Tue Oct 21 10:18:41 2014	(r2556)
+++ trunk/SDK/BON/Wizard/Templates/1033/BON2Component.cpp	Wed Oct 29 10:43:40 2014	(r2557)
@@ -94,11 +94,11 @@
 	project->setAutoCommit( false);
 #endif
 	using namespace GMEConsole;
-	Console::Out::WriteLine("Interpreter started...");
+	Console::Out::WriteLine(_T("Interpreter started..."));
 	// ======================
 	// TODO: Insert application specific code here
 
-	Console::Out::WriteLine("Interpreter completed...");
+	Console::Out::WriteLine(_T("Interpreter completed..."));
 }
 
 // ====================================================

Modified: trunk/SDK/BON/Wizard/Templates/1033/BONComponent.cpp
==============================================================================
--- trunk/SDK/BON/Wizard/Templates/1033/BONComponent.cpp	Tue Oct 21 10:18:41 2014	(r2556)
+++ trunk/SDK/BON/Wizard/Templates/1033/BONComponent.cpp	Wed Oct 29 10:43:40 2014	(r2557)
@@ -17,7 +17,7 @@
 void CComponent::InvokeEx(CBuilder &builder,CBuilderObject *focus, CBuilderObjectList &selected, long param) 
 {
 	using namespace GMEConsole;
-	Console::Out::WriteLine("Interpreter started...");
+	Console::Out::WriteLine(_T("Interpreter started..."));
 	AfxMessageBox(_T("GME Component --- Sample rf:") + builder.GetRootFolder()->GetName(), MB_OK | MB_ICONSTOP);
-	Console::Out::WriteLine("Interpreter completed...");
+	Console::Out::WriteLine(_T("Interpreter completed..."));
 }

Modified: trunk/SDK/BON/Wizard/Templates/1033/RawComponent.cpp
==============================================================================
--- trunk/SDK/BON/Wizard/Templates/1033/RawComponent.cpp	Tue Oct 21 10:18:41 2014	(r2556)
+++ trunk/SDK/BON/Wizard/Templates/1033/RawComponent.cpp	Wed Oct 29 10:43:40 2014	(r2557)
@@ -69,7 +69,7 @@
 			if (currentobj)
 				focusname = currentobj->Name;
 			using namespace GMEConsole;
-			Console::Out::WriteLine("Interpreter started...");
+			Console::Out::WriteLine(_T("Interpreter started..."));
 			AfxMessageBox(_T("RAW Com Component --- Plugin!!!! Sample (project: ") + project->Name +
 						_T(", focus: ") + focusname);
 			if (invokeExStartedATransaction)

Modified: trunk/SDK/BON/Wizard/setup11.js
==============================================================================
--- trunk/SDK/BON/Wizard/setup11.js	Tue Oct 21 10:18:41 2014	(r2556)
+++ trunk/SDK/BON/Wizard/setup11.js	Wed Oct 29 10:43:40 2014	(r2557)
@@ -11,7 +11,7 @@
 // the terms of this license. You must not remove this notice, or
 // any other, from this software.
 
-// Setup program for the GME Component Wizard for VC++ 10.0 (Visual Studio 2010)
+// Setup program for the GME Component Wizard for VC++ 11.0 (Visual Studio 2012)
 
 
 main();

Copied and modified: trunk/SDK/BON/Wizard/setup12.js (from r2556, trunk/SDK/BON/Wizard/setup11.js)
==============================================================================
--- trunk/SDK/BON/Wizard/setup11.js	Tue Oct 21 10:18:41 2014	(r2556, copy source)
+++ trunk/SDK/BON/Wizard/setup12.js	Wed Oct 29 10:43:40 2014	(r2557)
@@ -11,7 +11,7 @@
 // the terms of this license. You must not remove this notice, or
 // any other, from this software.
 
 // Setup program for the GME Component Wizard for VC++ 10.0 (Visual Studio 2010)
 
 
 main();
@@ -76,15 +76,15 @@
 
 	try
 	{
-		var strVC11Key = "HKLM\\Software\\Microsoft\\VisualStudio\\11.0\\Setup\\VC\\ProductDir";
-		strValue = WSShell.RegRead(strVC11Key);
+		var strVC12Key = "HKLM\\Software\\Microsoft\\VisualStudio\\12.0\\Setup\\VC\\ProductDir";
+		strValue = WSShell.RegRead(strVC12Key);
 	}
 	catch(e)
 	{
 		try
 		{
-			var strVC11Key_x64 = "HKLM\\Software\\Wow6432Node\\Microsoft\\VisualStudio\\11.0\\Setup\\VC\\ProductDir";
-			strValue = WSShell.RegRead(strVC11Key_x64);
+			var strVC12Key_x64 = "HKLM\\Software\\Wow6432Node\\Microsoft\\VisualStudio\\12.0\\Setup\\VC\\ProductDir";
+			strValue = WSShell.RegRead(strVC12Key_x64);
 		}
 		catch(e)
 		{
@@ -151,9 +151,9 @@
 			{
 				var strLine = fileSrc.ReadLine();
 				if(strLine.indexOf("Wizard=VsWizard.VsWizardEngine") != -1)
-					strLine = "Wizard=VsWizard.VsWizardEngine.11.0";
+					strLine = "Wizard=VsWizard.VsWizardEngine.12.0";
 				else if(strLine.indexOf("WIZARD_VERSION") != -1)
-					strLine = "Param=\"WIZARD_VERSION = 11.0\"";
+					strLine = "Param=\"WIZARD_VERSION = 12.0\"";
 				else if(strLine.indexOf("ABSOLUTE_PATH") != -1)
 					strLine = "Param=\"ABSOLUTE_PATH = " + strSourceFolder + "\"";
 				fileDest.WriteLine(strLine);
@@ -11,7 +11,7 @@
 // any other, from this software.
 
-// Setup program for the GME Component Wizard for VC++ 10.0 (Visual Studio 2010)
+// Setup program for the GME Component Wizard for VC++ 12.0 (Visual Studio 2013)
 
 


More information about the gme-commit mailing list